

Zetup
=====



|image0| |image1|

.. |image0| image:: http://www.gnu.org/graphics/lgplv3-88x31.png
   :target: https://gnu.org/licenses/lgpl.html
.. |image1| image:: https://img.shields.io/pypi/pyversions/zetup.svg
   :target: https://python.org



|image0| |image1|

.. |image0| image:: https://img.shields.io/pypi/v/zetup.svg
   :target: https://pypi.python.org/pypi/zetup
.. |image1| image:: https://img.shields.io/pypi/dd/zetup.svg
   :target: https://pypi.python.org/pypi/zetup



|image0| |Build status|

.. |image0| image:: https://travis-ci.org/userzimmermann/zetup.py.svg?branch=master
   :target: https://travis-ci.org/userzimmermann/zetup.py
.. |Build status| image:: https://ci.appveyor.com/api/projects/status/3wm8jnisoft5x7qr?svg=true
   :target: https://ci.appveyor.com/project/userzimmermann/zetup-py



Zimmermann's Python Package Setup
---------------------------------



-  https://bitbucket.org/userzimmermann/zetup.py
-  https://github.com/userzimmermann/zetup.py
-  https://www.openhub.net/p/python-zetup

